@@ -589,7 +589,16 @@ static MagickBooleanType ReadPSDLayer(Image *image,const size_t channels,
   {
     if (image->depth == 1)
       {
-        count=ReadBlob(image,(image->columns+7)/8,pixels);
+        if (image->compression != RLECompression)
+          count=ReadBlob(image,(image->columns+7)/8,pixels);
+        else
+          {
+            count=ReadBlob(image,(size_t) offsets[y],compact_pixels);
+            if (count != (ssize_t) offsets[y])
+              break;
+            count=DecodePSDPixels((size_t) offsets[y],compact_pixels,
+              (ssize_t) 123456,(size_t) ((image->columns+7)/8),pixels);
+          }
         if (count < (ssize_t) ((image->columns+7)/8))
           break;
       }
@@ -649,9 +658,13 @@ static MagickBooleanType ReadPSDLayer(Image *image,const size_t channels,
               if (image->depth == 1)
                 {
                   ssize_t
-                    bit;
+                    bit,
+                    number_bits;
 
-                  for (bit=0; bit < (ssize_t) (image->columns % 8); bit++)
+                  number_bits=image->columns-x;
+                  if (number_bits > 8)
+                    number_bits=8;
+                  for (bit=0; bit < number_bits; bit++)
                   {
                     indexes[x]=((((unsigned char) pixel) & (0x01 << (7-bit)))
                       != 0 ? 0 : 255);
@@ -940,15 +953,34 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           size_t
             quantum;
 
+          unsigned long
+            tag;
+
           /*
             Skip layers & masks.
           */
           quantum=psd_info.version == 1 ? 4UL : 8UL;
-          if (DiscardBlobBytes(image,length-quantum) == MagickFalse)
-            ThrowFileException(exception,CorruptImageError,
-              "UnexpectedEndOfFile",image->filename);
+          tag=ReadBlobMSBLong(image);
+          (void) tag;
+          count=ReadBlob(image,4,(unsigned char *) type);
+          if ((count == 0) || (LocaleNCompare(type,"8BIM",4) != 0))
+            {
+              if (DiscardBlobBytes(image,length-quantum-8) == MagickFalse)
+                ThrowFileException(exception,CorruptImageError,
+                  "UnexpectedEndOfFile",image->filename);
+            }
+          else
+            {
+              count=ReadBlob(image,4,(unsigned char *) type);
+              if ((count != 0) && (LocaleNCompare(type,"Lr16",4) == 0))
+                size=GetPSDSize(&psd_info,image);
+              else
+                if (DiscardBlobBytes(image,length-quantum-12) == MagickFalse)
+                  ThrowFileException(exception,CorruptImageError,
+                    "UnexpectedEndOfFile",image->filename);
+            }
         }
-      else
+      if (size != 0)
         {
           MagickOffsetType
             layer_offset;
@@ -1402,9 +1434,6 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     offsets=(MagickOffsetType *) RelinquishMagickMemory(offsets);
   if (image->colorspace == CMYKColorspace)
     (void) NegateImage(image,MagickFalse);
-  if ((number_layers == 1) && (image->next != (Image *) NULL) &&
-      (image->matte != MagickFalse))
-    DeleteImageFromList(&image);
   (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
