@@ -17,7 +17,7 @@
 %                               January 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -353,9 +353,6 @@ static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
   MagickBooleanType
     status;
 
-  register const IndexPacket
-    *indexes;
-
   register const PixelPacket
     *p;
 
@@ -392,7 +389,6 @@ static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
     p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetVirtualIndexQueue(image);
     bit=0;
     byte=0;
     for (x=0; x < (ssize_t) image->columns; x++)
