@@ -624,6 +624,7 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
   for (next=image; next != (Image *) NULL; next=GetNextImageInList(next))
   {
     char
+      magick_path[MaxTextExtent],
       *property,
       timestamp[MaxTextExtent];
 
@@ -634,17 +635,17 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       *profile;
 
     next->taint=MagickFalse;
-    if (next->magick_columns == 0)
-      next->magick_columns=next->columns;
-    if (next->magick_rows == 0)
-      next->magick_rows=next->rows;
-    if ((LocaleCompare(magick,"HTTP") != 0) &&
-        (LocaleCompare(magick,"FTP") != 0) && (LocaleCompare(magick,"X") != 0))
+    GetPathComponent(magick_filename,MagickPath,magick_path);
+    if (*magick_path == '\0')
       (void) CopyMagickString(next->magick,magick,MaxTextExtent);
     (void) CopyMagickString(next->magick_filename,magick_filename,
       MaxTextExtent);
     if (IsBlobTemporary(image) != MagickFalse)
       (void) CopyMagickString(next->filename,filename,MaxTextExtent);
+    if (next->magick_columns == 0)
+      next->magick_columns=next->columns;
+    if (next->magick_rows == 0)
+      next->magick_rows=next->rows;
     value=GetImageProperty(next,"tiff:Orientation");
     if (value == (char *) NULL)
       value=GetImageProperty(next,"exif:Orientation");
@@ -965,11 +966,11 @@ MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  WriteImage() writes an image or an image sequence to a file or filehandle.
-%  If writing to a file on disk, the name is defined by the filename member of
-%  the image structure.  Write() returns MagickFalse is these is a memory
-%  shortage or if the image cannot be written.  Check the exception member of
-%  image to determine the cause for any failure.
+%  WriteImage() writes an image or an image sequence to a file or file handle.
+%  If writing to a file is on disk, the name is defined by the filename member
+%  of the image structure.  WriteImage() returns MagickFalse is there is a
+%  memory shortage or if the image cannot be written.  Check the exception
+%  member of image to determine the cause for any failure.
 %
 %  The format of the WriteImage method is:
 %
@@ -1072,7 +1073,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
     }
   (void) SyncImageProfiles(image);
   option=GetImageOption(image_info,"delegate:bimodal");
-  if ((option != (const char *) NULL) && 
+  if ((option != (const char *) NULL) &&
       (IsMagickTrue(option) != MagickFalse) &&
       (write_info->page == (char *) NULL) &&
       (GetPreviousImageInList(image) == (Image *) NULL) &&
@@ -1172,7 +1173,14 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
           if ((magick_info == (const MagickInfo *) NULL) ||
               (GetImageEncoder(magick_info) == (EncodeImageHandler *) NULL))
             {
-              magick_info=GetMagickInfo(image->magick,&image->exception);
+              char
+                extension[MaxTextExtent];
+
+              GetPathComponent(image->filename,ExtensionPath,extension);
+              if (*extension != '\0')
+                magick_info=GetMagickInfo(extension,&image->exception);
+              else
+                magick_info=GetMagickInfo(image->magick,&image->exception);
               (void) CopyMagickString(image->filename,filename,MaxTextExtent);
             }
           if ((magick_info == (const MagickInfo *) NULL) ||
@@ -1228,7 +1236,14 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  WriteImages() writes an image sequence.
+%  WriteImages() writes an image sequence into one or more files.  While
+%  WriteImage() can write an image sequence, it is limited to writing
+%  the sequence into a single file using a format which supports multiple
+%  frames.   WriteImages(), however, does not have this limitation, instead it
+%  generates multiple output files if necessary (or when requested).  When
+%  ImageInfo's adjoin flag is set to MagickFalse, the file name is expected
+%  to include a printf-style formatting string for the frame number (e.g.
+%  "image%02d.png").
 %
 %  The format of the WriteImages method is:
 %
