@@ -150,32 +150,32 @@ struct _Image
     storage_class;
 
   ColorspaceType
-    colorspace;
+    colorspace;      /* colorspace of image data */
 
   CompressionType
-    compression;
+    compression;     /* compression of image when read/write */
 
   size_t
-    quality;
+    quality;         /* compression quality setting, meaning varies */
 
   OrientationType
-    orientation;
+    orientation;     /* photo orientation of image */
 
   MagickBooleanType
-    taint,
-    matte;
+    taint,           /* has image been modified since reading */
+    matte;           /* is transparency channel defined and active */
 
   size_t
-    columns,
+    columns,         /* physical size of image */
     rows,
-    depth,
-    colors;
+    depth,           /* depth of image on read/write */
+    colors;          /* size of color table on read */
 
   PixelPacket
     *colormap,
-    background_color,
-    border_color,
-    matte_color;
+    background_color, /* current background color attribute */
+    border_color,     /* current bordercolor attribute */
+    matte_color;      /* current mattecolor attribute */
 
   double
     gamma;
@@ -190,7 +190,7 @@ struct _Image
     *profiles;
 
   ResolutionType
-    units;
+    units;          /* resolution/density  ppi or ppc */
 
   char
     *montage,
@@ -201,46 +201,46 @@ struct _Image
     offset;
 
   double
-    x_resolution,
+    x_resolution,   /* image resolution/density */
     y_resolution;
 
   RectangleInfo
-    page,
+    page,           /* virtual canvas size and offset of image */
     extract_info,
-    tile_info;  /* deprecated */
+    tile_info;      /* deprecated */
 
   double
     bias,
-    blur,  /* deprecated */
-    fuzz;
+    blur,           /* deprecated */
+    fuzz;           /* current color fuzz attribute */
 
   FilterTypes
-    filter;
+    filter;         /* resize/distort filter to apply */
 
   InterlaceType
     interlace;
 
   EndianType
-    endian;
+    endian;         /* raw data integer ordering on read/write */
 
   GravityType
-    gravity;
+    gravity;        /* Gravity attribute for positioning in image */
 
   CompositeOperator
-    compose;
+    compose;        /* alpha composition method for layered images */
 
   DisposeType
-    dispose;
+    dispose;        /* GIF animation disposal method */
 
   struct _Image
     *clip_mask;
 
   size_t
-    scene,
-    delay;
+    scene,          /* index of image in multi-image file */
+    delay;          /* Animation delay time */
 
   ssize_t
-    ticks_per_second;
+    ticks_per_second;  /* units for delay time, default 100 for GIF */
 
   size_t
     iterations,
@@ -261,7 +261,7 @@ struct _Image
   void
     *client_data,
     *cache,
-    *attributes;  /* deprecated */
+    *attributes;      /* deprecated */
 
   Ascii85Info
     *ascii85;
@@ -270,7 +270,7 @@ struct _Image
     *blob;
 
   char
-    filename[MaxTextExtent],
+    filename[MaxTextExtent],   /* images input filename */
     magick_filename[MaxTextExtent],
     magick[MaxTextExtent];
 
@@ -279,10 +279,10 @@ struct _Image
     magick_rows;
 
   ExceptionInfo
-    exception;
+    exception;        /* Error handling report */
 
   MagickBooleanType
-    debug;
+    debug;            /* debug output attribute */
 
   volatile ssize_t
     reference_count;
@@ -302,18 +302,18 @@ struct _Image
     signature;
 
   struct _Image
-    *previous,
+    *previous,         /* Image sequence list links */
     *list,
     *next;
 
   InterpolatePixelMethod
-    interpolate;
+    interpolate;       /* Interpolation of color for between pixel lookups */
 
   MagickBooleanType
     black_point_compensation;
 
   PixelPacket
-    transparent_color;
+    transparent_color; /* color for 'transparent' color index in GIF */
 
   struct _Image
     *mask;
@@ -322,14 +322,14 @@ struct _Image
     tile_offset;
 
   void
-    *properties,
-    *artifacts;
+    *properties,       /* per image properities */
+    *artifacts;        /* per image sequence image artifacts */
 
   ImageType
     type;
 
   MagickBooleanType
-    dither;
+    dither;            /* dithering method during color reduction */
 
   MagickSizeType
     extent;
@@ -338,6 +338,7 @@ struct _Image
     ping;
 };
 
+
 struct _ImageInfo
 {
   CompressionType
@@ -499,7 +500,9 @@ extern MagickExport Image
   *NewMagickImage(const ImageInfo *,const size_t,const size_t,
     const MagickPixelPacket *),
   *ReferenceImage(Image *),
-  *SeparateImages(const Image *,const ChannelType,ExceptionInfo *);
+  *SeparateImages(const Image *,const ChannelType,ExceptionInfo *),
+  *SmushImages(const Image *,const MagickBooleanType,const ssize_t,
+    ExceptionInfo *);
 
 extern MagickExport ImageInfo
   *AcquireImageInfo(void),
