@@ -328,14 +328,12 @@ static RadonInfo *DestroyRadonInfo(RadonInfo *radon_info)
 
 static MagickBooleanType ResetRadonCells(RadonInfo *radon_info)
 {
-  ssize_t
-    y;
-
   register ssize_t
     x;
 
   ssize_t
-    count;
+    count,
+    y;
 
   unsigned short
     value;
@@ -346,7 +344,7 @@ static MagickBooleanType ResetRadonCells(RadonInfo *radon_info)
       return(MagickTrue);
     }
   value=0;
-  (void) MagickSeek(radon_info->file,0,SEEK_SET);
+  (void) lseek(radon_info->file,0,SEEK_SET);
   for (y=0; y < (ssize_t) radon_info->height; y++)
   {
     for (x=0; x < (ssize_t) radon_info->width; x++)
@@ -439,7 +437,7 @@ static inline size_t MagickMin(const size_t x,const size_t y)
 }
 
 static inline ssize_t ReadRadonCell(const RadonInfo *radon_info,
-  const off_t offset,const size_t length,unsigned char *buffer)
+  const MagickOffsetType offset,const size_t length,unsigned char *buffer)
 {
   register ssize_t
     i;
@@ -453,7 +451,7 @@ static inline ssize_t ReadRadonCell(const RadonInfo *radon_info,
 #endif
   {
     i=(-1);
-    if (MagickSeek(radon_info->file,offset,SEEK_SET) >= 0)
+    if (lseek(radon_info->file,offset,SEEK_SET) >= 0)
       {
 #endif
         count=0;
@@ -464,7 +462,7 @@ static inline ssize_t ReadRadonCell(const RadonInfo *radon_info,
             SSIZE_MAX));
 #else
           count=pread(radon_info->file,buffer+i,MagickMin(length-i,(size_t)
-            SSIZE_MAX),(off_t) (offset+i));
+            SSIZE_MAX),offset+i);
 #endif
           if (count > 0)
             continue;
@@ -483,7 +481,7 @@ static inline ssize_t ReadRadonCell(const RadonInfo *radon_info,
 }
 
 static inline ssize_t WriteRadonCell(const RadonInfo *radon_info,
-  const off_t offset,const size_t length,const unsigned char *buffer)
+  const MagickOffsetType offset,const size_t length,const unsigned char *buffer)
 {
   register ssize_t
     i;
@@ -496,7 +494,7 @@ static inline ssize_t WriteRadonCell(const RadonInfo *radon_info,
   #pragma omp critical (MagickCore_WriteRadonCell)
 #endif
   {
-    if (MagickSeek(radon_info->file,offset,SEEK_SET) >= 0)
+    if (lseek(radon_info->file,offset,SEEK_SET) >= 0)
       {
 #endif
         count=0;
@@ -507,7 +505,7 @@ static inline ssize_t WriteRadonCell(const RadonInfo *radon_info,
             SSIZE_MAX));
 #else
           count=pwrite(radon_info->file,buffer+i,MagickMin(length-i,(size_t)
-            SSIZE_MAX),(off_t) (offset+i));
+            SSIZE_MAX),offset+i);
 #endif
           if (count > 0)
             continue;
@@ -528,13 +526,13 @@ static inline ssize_t WriteRadonCell(const RadonInfo *radon_info,
 static inline unsigned short GetRadonCell(const RadonInfo *radon_info,
   const ssize_t x,const ssize_t y)
 {
-  off_t
+  MagickOffsetType
     i;
 
   unsigned short
     value;
 
-  i=(off_t) radon_info->height*x+y;
+  i=(MagickOffsetType) radon_info->height*x+y;
   if ((i < 0) ||
       ((MagickSizeType) (i*sizeof(*radon_info->cells)) >= radon_info->length))
     return(0);
@@ -549,13 +547,13 @@ static inline unsigned short GetRadonCell(const RadonInfo *radon_info,
 static inline MagickBooleanType SetRadonCell(const RadonInfo *radon_info,
   const ssize_t x,const ssize_t y,const unsigned short value)
 {
-  off_t
+  MagickOffsetType
     i;
 
   ssize_t
     count;
 
-  i=(off_t) radon_info->height*x+y;
+  i=(MagickOffsetType) radon_info->height*x+y;
   if ((i < 0) ||
       ((MagickSizeType) (i*sizeof(*radon_info->cells)) >= radon_info->length))
     return(MagickFalse);
@@ -593,12 +591,12 @@ static void RadonProjection(RadonInfo *source_cells,
   {
     for (x=0; x < (ssize_t) p->width; x+=2*(ssize_t) step)
     {
-      ssize_t
-        y;
-
       register ssize_t
         i;
 
+      ssize_t
+        y;
+
       unsigned short
         cell;
 
@@ -661,9 +659,6 @@ static MagickBooleanType RadonTransform(const Image *image,
   CacheView
     *image_view;
 
-  ssize_t
-    y;
-
   MagickBooleanType
     status;
 
@@ -674,13 +669,16 @@ static MagickBooleanType RadonTransform(const Image *image,
   register ssize_t
     i;
 
-  unsigned char
-    byte;
-
   size_t
     count,
     width;
 
+  ssize_t
+    y;
+
+  unsigned char
+    byte;
+
   unsigned short
     bits[256];
 
@@ -824,15 +822,15 @@ static void GetImageBackgroundColor(Image *image,const ssize_t offset,
   CacheView
     *image_view;
 
-  ssize_t
-    y;
-
   MagickPixelPacket
     background;
 
   MagickRealType
     count;
 
+  ssize_t
+    y;
+
   /*
     Compute average background color.
   */
@@ -895,9 +893,6 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
     *deskew_image,
     *median_image;
 
-  ssize_t
-    skew;
-
   MagickBooleanType
     status;
 
@@ -912,6 +907,9 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
     *projection,
     width;
 
+  ssize_t
+    skew;
+
   /*
     Compute deskew angle.
   */
@@ -970,7 +968,7 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
   clone_image=DestroyImage(clone_image);
   if (deskew_image == (Image *) NULL)
     return((Image *) NULL);
-  median_image=MedianFilterImage(deskew_image,0.0,exception);
+  median_image=StatisticImage(deskew_image,MedianStatistic,3,3,exception);
   if (median_image == (Image *) NULL)
     {
       deskew_image=DestroyImage(deskew_image);
@@ -1072,13 +1070,13 @@ static Image *IntegralRotateImage(const Image *image,size_t rotations,
     }
     case 1:
     {
-      ssize_t
-        tile_y;
-
       size_t
         tile_height,
         tile_width;
 
+      ssize_t
+        tile_y;
+
       /*
         Rotate 90 degrees.
       */
@@ -1263,13 +1261,13 @@ static Image *IntegralRotateImage(const Image *image,size_t rotations,
     }
     case 3:
     {
-      ssize_t
-        tile_y;
-
       size_t
         tile_height,
         tile_width;
 
+      ssize_t
+        tile_y;
+
       /*
         Rotate 270 degrees.
       */
@@ -1466,7 +1464,7 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
   if (image->colorspace == CMYKColorspace)
     ConvertRGBToCMYK(&background);
   /*
-    XShear image.
+    X shear image.
   */
   status=MagickTrue;
   progress=0;
@@ -1476,9 +1474,6 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
 #endif
   for (y=0; y < (ssize_t) height; y++)
   {
-    ssize_t
-      step;
-
     MagickPixelPacket
       pixel,
       source,
@@ -1488,9 +1483,6 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
       area,
       displacement;
 
-    register ssize_t
-      i;
-
     register IndexPacket
       *restrict indexes,
       *restrict shear_indexes;
@@ -1499,9 +1491,15 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
       *restrict p,
       *restrict q;
 
+    register ssize_t
+      i;
+
     ShearDirection
       direction;
 
+    ssize_t
+      step;
+
     if (status == MagickFalse)
       continue;
     p=GetCacheViewAuthenticPixels(image_view,0,y_offset+y,image->columns,1,
