@@ -106,9 +106,6 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
   Image
     *chop_image;
 
-  ssize_t
-    y;
-
   MagickBooleanType
     status;
 
@@ -118,6 +115,9 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
   RectangleInfo
     extent;
 
+  ssize_t
+    y;
+
   /*
     Check chop geometry.
   */
@@ -1191,12 +1191,12 @@ static inline MagickBooleanType CopyImageRegion(Image *destination,
     *source_view,
     *destination_view;
 
-  ssize_t
-    y;
-
   MagickBooleanType
     status;
 
+  ssize_t
+    y;
+
   status=MagickTrue;
   source_view=AcquireCacheView(source);
   destination_view=AcquireCacheView(destination);
@@ -1416,7 +1416,6 @@ MagickExport Image *SpliceImage(const Image *image,
     *splice_image;
 
   MagickBooleanType
-    proceed,
     status;
 
   MagickOffsetType
@@ -1425,9 +1424,6 @@ MagickExport Image *SpliceImage(const Image *image,
   RectangleInfo
     splice_geometry;
 
-  register ssize_t
-    i;
-
   ssize_t
     y;
 
@@ -1512,7 +1508,6 @@ MagickExport Image *SpliceImage(const Image *image,
     Splice image.
   */
   status=MagickTrue;
-  i=0;
   progress=0;
   image_view=AcquireCacheView(image);
   splice_view=AcquireCacheView(splice_image);
@@ -1576,8 +1571,6 @@ MagickExport Image *SpliceImage(const Image *image,
     }
     if (SyncCacheViewAuthenticPixels(splice_view,exception) == MagickFalse)
       status=MagickFalse;
-    proceed=SetImageProgress(image,SpliceImageTag,(MagickOffsetType) y,
-      splice_image->rows);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
       {
         MagickBooleanType
@@ -1709,6 +1702,7 @@ MagickExport Image *SpliceImage(const Image *image,
 %      final size of the image.
 %
 */
+
 static inline ssize_t MagickRound(MagickRealType x)
 {
   /*
@@ -1727,10 +1721,6 @@ MagickExport MagickBooleanType TransformImage(Image **image,
     *resize_image,
     *transform_image;
 
-  ssize_t
-    x,
-    y;
-
   MagickStatusType
     flags;
 
@@ -1741,6 +1731,10 @@ MagickExport MagickBooleanType TransformImage(Image **image,
     height,
     width;
 
+  ssize_t
+    x,
+    y;
+
   assert(image != (Image **) NULL);
   assert((*image)->signature == MagickSignature);
   if ((*image)->debug != MagickFalse)
