@@ -27,14 +27,14 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2011 ImageMagick Studio LLC"
-#define MagickLibVersion  0x667
-#define MagickLibVersionText  "6.6.7"
+#define MagickLibVersion  0x668
+#define MagickLibVersionText  "6.6.8"
 #define MagickLibVersionNumber  4,0,1
 #define MagickLibAddendum  "-10"
 #define MagickLibInterface  4
 #define MagickLibMinInterface  4
-#define MagickReleaseDate  "2011-02-25"
-#define MagickChangeDate   "20110223"
+#define MagickReleaseDate  "2011-03-27"
+#define MagickChangeDate   "20110327"
 #define MagickAuthoritativeURL  "http://www.imagemagick.org"
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
 #define MagickOpenMPFeature  "OpenMP "
@@ -52,7 +52,7 @@ extern "C" {
 #define MagickHDRIFeature  " "
 #endif
 #define MagickFeatures MagickOpenMPFeature MagickOpenCLFeature MagickHDRIFeature
-#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.6.7/index.html"
+#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.6.8//index.html"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
