@@ -174,13 +174,13 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
         else
           if (composite_options->tile != MagickFalse)
             {
+              size_t
+                columns;
+
               ssize_t
                 x,
                 y;
 
-              size_t
-                columns;
-
               /*
                 Tile the composite image.
               */
@@ -427,18 +427,19 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
 
   MagickBooleanType
     fire,
-    pend;
+    pend,
+    respect_parenthesis;
 
   MagickStatusType
     status;
 
+  register ssize_t
+    i;
+
   ssize_t
     j,
     k;
 
-  register ssize_t
-    i;
-
   /*
     Set default.
   */
@@ -470,6 +471,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
+  respect_parenthesis=MagickFalse;
   status=MagickTrue;
   /*
     Check command syntax.
@@ -1130,6 +1132,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             if (i == (ssize_t) argc)
               ThrowCompositeException(OptionError,"MissingArgument",option);
             value=strtod(argv[i],&p);
+            (void) value;
             if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
