@@ -212,7 +212,9 @@ static MagickBooleanType MontageUsage(void)
     },
     *stack_operators[]=
     {
-      "-clone index         clone an image",
+      "-clone indexes       clone an image",
+      "-duplicate count,indexes",
+      "                     duplicate an image one or more times",
       (char *) NULL
     };
 
@@ -299,14 +301,10 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
     first_scene,
     last_scene;
 
-  ssize_t
-    j,
-    k,
-    scene;
-
   MagickBooleanType
     fire,
-    pend;
+    pend,
+    respect_parenthesis;
 
   MagickStatusType
     status;
@@ -317,6 +315,11 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   register ssize_t
     i;
 
+  ssize_t
+    j,
+    k,
+    scene;
+
   /*
     Set defaults.
   */
@@ -350,6 +353,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
+  respect_parenthesis=MagickFalse;
   scene=0;
   status=MagickFalse;
   transparent_color=(char *) NULL;
@@ -836,6 +840,17 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("duplicate",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (ssize_t) (argc-1))
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowMontageInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("duration",option+1) == 0)
           {
             if (*option == '+')
@@ -1120,6 +1135,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             if (i == (ssize_t) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
             value=strtod(argv[i],&p);
+            (void) value;
             if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
@@ -1174,6 +1190,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             MontageMode
               mode;
 
+            (void) CopyMagickString(argv[i]+1,"sans",MaxTextExtent);
             if (*option == '+')
               break;
             i++;
