@@ -81,7 +81,6 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
 static MagickBooleanType StreamUsage(void)
@@ -199,13 +198,10 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
   ImageStack
     image_stack[MaxImageStackDepth+1];
 
-  ssize_t
-    j,
-    k;
-
   MagickBooleanType
     fire,
-    pend;
+    pend,
+    respect_parenthesis;
 
   MagickStatusType
     status;
@@ -213,6 +209,10 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
   register ssize_t
     i;
 
+  ssize_t
+    j,
+    k;
+
   StreamInfo
     *stream_info;
 
@@ -241,11 +241,13 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
   if (argc < 3)
     return(StreamUsage());
   format="%w,%h,%m";
+  (void) format;
   j=1;
   k=0;
   NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
+  respect_parenthesis=MagickFalse;
   stream_info=AcquireStreamInfo(image_info);
   status=MagickTrue;
   /*
@@ -544,6 +546,7 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
             if (i == (ssize_t) argc)
               ThrowStreamException(OptionError,"MissingArgument",option);
             value=strtod(argv[i],&p);
+            (void) value;
             if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowStreamInvalidArgumentException(option,argv[i]);
             break;
