@@ -22,7 +22,7 @@
 %                                March 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -127,7 +127,7 @@ WandExport WandView *CloneWandView(const WandView *wand_view)
   assert(wand_view->signature == WandSignature);
   if (wand_view->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand_view->name);
-  clone_view=(WandView *) AcquireAlignedMemory(1,sizeof(*clone_view));
+  clone_view=(WandView *) AcquireMagickMemory(sizeof(*clone_view));
   if (clone_view == (WandView *) NULL)
     ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       wand_view->name);
@@ -184,7 +184,7 @@ static PixelWand ***DestroyPixelsThreadSet(PixelWand ***pixel_wands,
   for (i=0; i < (ssize_t) number_threads; i++)
     if (pixel_wands[i] != (PixelWand **) NULL)
       pixel_wands[i]=DestroyPixelWands(pixel_wands[i],number_wands);
-  pixel_wands=(PixelWand ***) RelinquishAlignedMemory(pixel_wands);
+  pixel_wands=(PixelWand ***) RelinquishMagickMemory(pixel_wands);
   return(pixel_wands);
 }
 
@@ -287,10 +287,13 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
   progress=0;
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status)
+  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(source->number_threads)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
+    const int
+      id = GetOpenMPThreadId();
+
     MagickBooleanType
       sync;
 
@@ -306,7 +309,6 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
       *restrict destination_indexes;
 
     register ssize_t
-      id,
       x;
 
     register PixelPacket
@@ -314,7 +316,6 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
 
     if (status == MagickFalse)
       continue;
-    id=GetOpenMPThreadId();
     pixels=GetCacheViewVirtualPixels(source->view,source->extent.x,y,
       source->extent.width,1,source->exception);
     if (pixels == (const PixelPacket *) NULL)
@@ -552,10 +553,13 @@ WandExport MagickBooleanType GetWandViewIterator(WandView *source,
   status=MagickTrue;
   progress=0;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status)
+  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(source->number_threads)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
+    const int
+      id = GetOpenMPThreadId();
+
     register const IndexPacket
       *indexes;
 
@@ -563,12 +567,10 @@ WandExport MagickBooleanType GetWandViewIterator(WandView *source,
       *pixels;
 
     register ssize_t
-      id,
       x;
 
     if (status == MagickFalse)
       continue;
-    id=GetOpenMPThreadId();
     pixels=GetCacheViewVirtualPixels(source->view,source->extent.x,y,
       source->extent.width,1,source->exception);
     if (pixels == (const PixelPacket *) NULL)
@@ -628,12 +630,11 @@ WandExport MagickBooleanType GetWandViewIterator(WandView *source,
 */
 WandExport PixelWand **GetWandViewPixels(const WandView *wand_view)
 {
-  ssize_t
-    id;
+  const int
+    id = GetOpenMPThreadId();
 
   assert(wand_view != (WandView *) NULL);
   assert(wand_view->signature == WandSignature);
-  id=GetOpenMPThreadId();
   return(wand_view->pixel_wands[id]);
 }
 
@@ -737,7 +738,7 @@ static PixelWand ***AcquirePixelsThreadSet(const size_t number_wands,
   register ssize_t
     i;
 
-  pixel_wands=(PixelWand ***) AcquireAlignedMemory(number_threads,
+  pixel_wands=(PixelWand ***) AcquireQuantumMemory(number_threads,
     sizeof(*pixel_wands));
   if (pixel_wands == (PixelWand ***) NULL)
     return((PixelWand ***) NULL);
@@ -758,7 +759,7 @@ WandExport WandView *NewWandView(MagickWand *wand)
 
   assert(wand != (MagickWand *) NULL);
   assert(wand->signature == WandSignature);
-  wand_view=(WandView *) AcquireAlignedMemory(1,sizeof(*wand_view));
+  wand_view=(WandView *) AcquireMagickMemory(sizeof(*wand_view));
   if (wand_view == (WandView *) NULL)
     ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       GetExceptionMessage(errno));
@@ -818,7 +819,7 @@ WandExport WandView *NewWandViewExtent(MagickWand *wand,const ssize_t x,
 
   assert(wand != (MagickWand *) NULL);
   assert(wand->signature == WandSignature);
-  wand_view=(WandView *) AcquireAlignedMemory(1,sizeof(*wand_view));
+  wand_view=(WandView *) AcquireMagickMemory(sizeof(*wand_view));
   if (wand_view == (WandView *) NULL)
     ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       GetExceptionMessage(errno));
@@ -950,10 +951,13 @@ WandExport MagickBooleanType SetWandViewIterator(WandView *destination,
   progress=0;
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status)
+  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(destination->number_threads)
 #endif
   for (y=destination->extent.y; y < (ssize_t) destination->extent.height; y++)
   {
+    const int
+      id = GetOpenMPThreadId();
+
     MagickBooleanType
       sync;
 
@@ -961,7 +965,6 @@ WandExport MagickBooleanType SetWandViewIterator(WandView *destination,
       *restrict indexes;
 
     register ssize_t
-      id,
       x;
 
     register PixelPacket
@@ -969,7 +972,6 @@ WandExport MagickBooleanType SetWandViewIterator(WandView *destination,
 
     if (status == MagickFalse)
       continue;
-    id=GetOpenMPThreadId();
     pixels=GetCacheViewAuthenticPixels(destination->view,destination->extent.x,
       y,destination->extent.width,1,exception);
     if (pixels == (PixelPacket *) NULL)
@@ -1016,6 +1018,41 @@ WandExport MagickBooleanType SetWandViewIterator(WandView *destination,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   S e t W a n d V i e w T h r e a d s                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetWandViewThreads() sets the number of threads in a thread team.
+%
+%  The format of the SetWandViewDescription method is:
+%
+%      void SetWandViewThreads(WandView *image_view,
+%        const size_t number_threads)
+%
+%  A description of each parameter follows:
+%
+%    o image_view: the image view.
+%
+%    o number_threads: the number of threads in a thread team.
+%
+*/
+MagickExport void SetWandViewThreads(WandView *image_view,
+  const size_t number_threads)
+{
+  assert(image_view != (WandView *) NULL);
+  assert(image_view->signature == MagickSignature);
+  image_view->number_threads=number_threads;
+  if (number_threads > GetOpenMPMaximumThreads())
+    image_view->number_threads=GetOpenMPMaximumThreads();
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   T r a n s f e r W a n d V i e w I t e r a t o r                           %
 %                                                                             %
 %                                                                             %
@@ -1090,10 +1127,13 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
   progress=0;
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status)
+  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(source->number_threads)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
+    const int
+      id = GetOpenMPThreadId();
+
     MagickBooleanType
       sync;
 
@@ -1107,7 +1147,6 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
       *restrict destination_indexes;
 
     register ssize_t
-      id,
       x;
 
     register PixelPacket
@@ -1115,7 +1154,6 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
 
     if (status == MagickFalse)
       continue;
-    id=GetOpenMPThreadId();
     pixels=GetCacheViewVirtualPixels(source->view,source->extent.x,y,
       source->extent.width,1,source->exception);
     if (pixels == (const PixelPacket *) NULL)
@@ -1253,15 +1291,17 @@ WandExport MagickBooleanType UpdateWandViewIterator(WandView *source,
   progress=0;
   exception=source->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,1) shared(progress,status)
+  #pragma omp parallel for schedule(static,1) shared(progress,status) num_threads(source->number_threads)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
+    const int
+      id = GetOpenMPThreadId();
+
     register IndexPacket
       *restrict indexes;
 
     register ssize_t
-      id,
       x;
 
     register PixelPacket
@@ -1269,7 +1309,6 @@ WandExport MagickBooleanType UpdateWandViewIterator(WandView *source,
 
     if (status == MagickFalse)
       continue;
-    id=GetOpenMPThreadId();
     pixels=GetCacheViewAuthenticPixels(source->view,source->extent.x,y,
       source->extent.width,1,exception);
     if (pixels == (PixelPacket *) NULL)
